@@ -18,11 +18,11 @@ import org.gcube.common.homelibrary.home.workspace.WorkspaceItem;
 import org.gcube.common.homelibrary.home.workspace.folder.items.GCubeItem;
 import org.gcube.common.portal.PortalContext;
 import org.gcube.common.scope.api.ScopeProvider;
-import org.gcube.datacatalogue.ckanutillibrary.ApplicationProfileScopePerUrlReader;
-import org.gcube.datacatalogue.ckanutillibrary.DataCatalogue;
-import org.gcube.datacatalogue.ckanutillibrary.models.RolesCkanGroupOrOrg;
-import org.gcube.datacatalogue.ckanutillibrary.utils.SessionCatalogueAttributes;
-import org.gcube.datacatalogue.ckanutillibrary.utils.UtilMethods;
+import org.gcube.datacatalogue.ckanutillibrary.server.ApplicationProfileScopePerUrlReader;
+import org.gcube.datacatalogue.ckanutillibrary.server.DataCatalogue;
+import org.gcube.datacatalogue.ckanutillibrary.server.utils.SessionCatalogueAttributes;
+import org.gcube.datacatalogue.ckanutillibrary.server.utils.UtilMethods;
+import org.gcube.datacatalogue.ckanutillibrary.shared.RolesCkanGroupOrOrg;
 import org.gcube.datacatalogue.metadatadiscovery.DataCalogueMetadataFormatReader;
 import org.gcube.datacatalogue.metadatadiscovery.bean.MetadataType;
 import org.gcube.datacatalogue.metadatadiscovery.bean.jaxb.MetadataField;
@@ -47,9 +47,10 @@ import org.gcube.vomanagement.usermanagement.model.GCubeGroup;
 import org.gcube.vomanagement.usermanagement.model.GCubeRole;
 import org.gcube.vomanagement.usermanagement.model.GCubeUser;
 import org.gcube.vomanagement.usermanagement.model.GatewayRolesNames;
-import org.slf4j.LoggerFactory;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
+import com.liferay.portal.kernel.log.Log;
+import com.liferay.portal.kernel.log.LogFactoryUtil;
 
 import eu.trentorise.opendata.jackan.internal.org.apache.http.HttpEntity;
 import eu.trentorise.opendata.jackan.internal.org.apache.http.HttpResponse;
@@ -67,11 +68,12 @@ import eu.trentorise.opendata.jackan.model.CkanOrganization;
 public class Utils {
 
 	// Logger
-	private static final org.slf4j.Logger logger = LoggerFactory.getLogger(Utils.class);
+	//private static final org.slf4j.Logger logger = LoggerFactory.getLogger(Utils.class);
+	private static final Log logger = LogFactoryUtil.getLog(Utils.class);
 	private static final String APPLICATION_ID_CATALOGUE_MANAGER = "org.gcube.datacatalogue.ProductCatalogue"; 
 	private static final String NOTIFICATION_MESSAGE = "Dear members,<br>The product 'PRODUCT_TITLE' has been just published by USER_FULLNAME.<br>You can find it here: PRODUCT_URL <br>";
-	private static final String SOCIAL_SERVICE_APPLICATION_TOKEN = "2/tokens/generate-application-token/";
-	private static final String SOCIAL_SERVICE_WRITE_APPLICATION_POST = "2/posts/write-post-app/";
+	private static final String SOCIAL_SERVICE_APPLICATION_TOKEN = "/2/tokens/generate-application-token/";
+	private static final String SOCIAL_SERVICE_WRITE_APPLICATION_POST = "/2/posts/write-post-app/";
 	private static final String MEDIATYPE_JSON = "application/json";
 	public static final String GCUBE_REQUEST_URL = "gcube-request-url";
 
@@ -101,15 +103,18 @@ public class Utils {
 	}
 
 	/**
-	 * Retrieve the list of organizations in which the user has the admin/editor role 
+	 * Retrieve the highest ckan role the user has and also retrieve the list of organizations (scopes) in which the user has the ckan-admin or ckan-editor role
 	 * @param currentScope the current scope 
 	 * @param username  the current username
 	 * @param groupName the current groupName
-	 * @param ckanPublisherServicesImpl 
+	 * @param gcubeCkanDataCatalogServiceImpl 
+	 * @param orgsInWhichAdminRole 
+	 * @param ckanUtils ckanUtils
 	 */
-	public static List<OrganizationBean> getUserOrganizationsListAdminEditor(String currentScope, String username, String groupName, CKANPublisherServicesImpl ckanPublisherServicesImpl){
+	public static RolesCkanGroupOrOrg getHighestRole(String currentScope, String username, String groupName, CKANPublisherServicesImpl gcubeCkanDataCatalogServiceImpl, List<OrganizationBean> orgsInWhichAtLeastEditorRole){
 
-		List<OrganizationBean> toReturn = new ArrayList<OrganizationBean>();
+		// base role as default value
+		RolesCkanGroupOrOrg toReturn = RolesCkanGroupOrOrg.MEMBER;
 
 		try{
 
@@ -125,36 +130,43 @@ public class Utils {
 
 			logger.debug("Group id is " + currentGroupId + " and scope is " + currentScope);
 
-			// retrieve the flat list of organizations
+			// retrieve the flat list of organizations for the current user
 			List<GCubeGroup> groups = groupManager.listGroupsByUser(userid);
 
 			// root (so check into the root, the VOs and the VRES)
 			if(groupManager.isRootVO(currentGroupId)){
 
-				logger.debug("The list of organizations of the user " + username + " is " + groups);
+				logger.info("The current scope is the Root Vo, so the list of organizations of the user " + username + " is " + groups);
 
 				for (GCubeGroup gCubeGroup : groups) {
 
-					// get the name of this vre
-					String gCubeGroupName = gCubeGroup.getGroupName();
-
-					// get the role of the users in this vre
-					List<GCubeRole> roles = roleManager.listRolesByUserAndGroup(userid, groupManager.getGroupId(gCubeGroupName));
-
-					// get highest role according liferay
-					RolesCkanGroupOrOrg correspondentRoleToCheck = getLiferayHighestRoleInOrg(roles);
-
-					// this is a tricky part...  because we actually do not know if it is a member or there is no ckan instance there
-					if(correspondentRoleToCheck.equals(RolesCkanGroupOrOrg.MEMBER))
+					if(!groupManager.isVRE(gCubeGroup.getGroupId()))
 						continue;
 
-					checkIfRoleIsSetInCkanInstance(username, gCubeGroupName, gCubeGroup.getGroupId(), correspondentRoleToCheck, toReturn, groupManager, ckanPublisherServicesImpl);
+					// get the name of this group
+					String gCubeGroupName = gCubeGroup.getGroupName();
+
+					// get the role of the users in this group
+					List<GCubeRole> roles = roleManager.listRolesByUserAndGroup(userid, groupManager.getGroupId(gCubeGroupName));
+
+					// get highest role
+					RolesCkanGroupOrOrg correspondentRoleToCheck = getLiferayHighestRoleInOrg(roles);
+
+					// be sure it is so
+					checkIfRoleIsSetInCkanInstance(username, gCubeGroupName, gCubeGroup.getGroupId(), 
+							correspondentRoleToCheck, groupManager, gcubeCkanDataCatalogServiceImpl, orgsInWhichAtLeastEditorRole);
+
+					toReturn = RolesCkanGroupOrOrg.getHigher(toReturn, correspondentRoleToCheck);
+
 				}
 
 			}else if(groupManager.isVO(currentGroupId)){
 
+				logger.debug("The list of organizations of the user " + username + " to scan is the one under the VO " + groupName);
+
 				for (GCubeGroup gCubeGroup : groups) {
 
+					// if the gCubeGroup is not under the VO or it is not the VO continue
 					if(currentGroupId != gCubeGroup.getParentGroupId() || currentGroupId != gCubeGroup.getGroupId())
 						continue;
 
@@ -162,31 +174,38 @@ public class Utils {
 
 					List<GCubeRole> roles = roleManager.listRolesByUserAndGroup(userid, groupManager.getGroupId(gCubeGroupName));
 
-					// get highest role according liferay
-					RolesCkanGroupOrOrg correspondentRoleToCheck =  getLiferayHighestRoleInOrg(roles);
+					// get highest role
+					RolesCkanGroupOrOrg correspondentRoleToCheck = getLiferayHighestRoleInOrg(roles);
 
-					// this is a tricky part...  because we actually do not know if it is a member or there is no ckan instance there
-					if(correspondentRoleToCheck.equals(RolesCkanGroupOrOrg.MEMBER))
-						continue;
+					// be sure it is so
+					checkIfRoleIsSetInCkanInstance(username, gCubeGroupName, gCubeGroup.getGroupId(), 
+							correspondentRoleToCheck, groupManager, gcubeCkanDataCatalogServiceImpl, orgsInWhichAtLeastEditorRole);
 
-					checkIfRoleIsSetInCkanInstance(username, gCubeGroupName, gCubeGroup.getGroupId(), correspondentRoleToCheck, toReturn, groupManager, ckanPublisherServicesImpl);
+					toReturn = RolesCkanGroupOrOrg.getHigher(toReturn, correspondentRoleToCheck);
 				}
 
-			}else if(groupManager.isVRE(currentGroupId)){ // vre
+			}else if(groupManager.isVRE(currentGroupId)){
 				List<GCubeRole> roles = roleManager.listRolesByUserAndGroup(userManager.getUserId(username), groupManager.getGroupId(groupName));
 
-				logger.debug("The list of roles for " + username + " into " + groupName + " is " + roles);
+				logger.debug("The current scope is the vre " + groupName);
 
-				// get highest role according liferay
-				RolesCkanGroupOrOrg correspondentRoleToCheck =  getLiferayHighestRoleInOrg(roles);
+				// get highest role
+				RolesCkanGroupOrOrg correspondentRoleToCheck = getLiferayHighestRoleInOrg(roles);
+
+				// be sure it is so
+				checkIfRoleIsSetInCkanInstance(username, groupName, currentGroupId, 
+						correspondentRoleToCheck, groupManager, gcubeCkanDataCatalogServiceImpl, orgsInWhichAtLeastEditorRole);
+
+				toReturn = correspondentRoleToCheck;
 
-				checkIfRoleIsSetInCkanInstance(username, groupName, currentGroupId, correspondentRoleToCheck, toReturn, groupManager, ckanPublisherServicesImpl);
 			}
 		}catch(Exception e){
 			logger.error("Unable to retrieve the role information for this user. Returning member role", e);
+			return RolesCkanGroupOrOrg.MEMBER;
 		}
 
-		logger.info("Retrieved orgs in which the user has admin roles " + toReturn);
+		// return the role
+		logger.debug("Returning role "  + toReturn + " for user " + username);
 		return toReturn;
 	}
 
@@ -205,7 +224,7 @@ public class Utils {
 	private static void checkIfRoleIsSetInCkanInstance(String username,
 			String gCubeGroupName, long groupId,
 			RolesCkanGroupOrOrg correspondentRoleToCheck,
-			List<OrganizationBean> orgs, GroupManager groupManager, CKANPublisherServicesImpl ckanPublisherServicesImpl) throws UserManagementSystemException, GroupRetrievalFault {
+			GroupManager groupManager, CKANPublisherServicesImpl ckanPublisherServicesImpl, List<OrganizationBean> orgs) throws UserManagementSystemException, GroupRetrievalFault {
 
 		// with this invocation, we check if the role is present in ckan and if it is not it will be added
 		DataCatalogue catalogue = ckanPublisherServicesImpl.getCatalogue(groupManager.getInfrastructureScope(groupId));
@@ -215,16 +234,11 @@ public class Utils {
 			boolean res = catalogue.checkRoleIntoOrganization(username, gCubeGroupName, correspondentRoleToCheck);
 			if(res && !correspondentRoleToCheck.equals(RolesCkanGroupOrOrg.MEMBER)){
 				// get the orgs of the user and retrieve its title and name
-				List<CkanOrganization> ckanOrgs = catalogue.getOrganizationsByUser(username);
-				for (CkanOrganization ckanOrganization : ckanOrgs) {
-					if(ckanOrganization.getName().equals(gCubeGroupName.toLowerCase())){
-						orgs.add(new OrganizationBean(ckanOrganization.getTitle(), ckanOrganization.getName()));
-						break;
-					}
-				}
+				CkanOrganization organization = catalogue.getOrganizationByName(gCubeGroupName.toLowerCase());
+				orgs.add(new OrganizationBean(organization.getTitle(), organization.getName()));
 			}
-		}
-
+		}else
+			logger.warn("It seems there is no ckan instance into scope " + groupManager.getInfrastructureScope(groupId));
 	}
 
 	/**
@@ -384,7 +398,7 @@ public class Utils {
 		String tokenUser = SecurityTokenProvider.instance.get();
 
 		logger.info("Current scope for writeProductPost is " + currentScope + " and token is " + tokenUser.substring(0, 10) + "***************");
-		String basePath = new ServiceEndPointReaderSocial(currentScope).getBasePath();
+		String basePath = new GCoreEndPointReaderSocial(currentScope).getBasePath();
 
 		if(basePath == null){
 
@@ -597,4 +611,5 @@ public class Utils {
 		return gm.getGroup(groupId);
 
 	}
+
 }
\ No newline at end of file
